@@ -38,7 +38,7 @@ node_levels <- function(net, order, lvl = 1, acc = NULL){
 #' plot_network(fit) # Works for both the structure and the fitted net
 #' }
 #' @export
-plot_network <- function(structure){
+plot_static_network <- function(structure){
   check_opt_pkgs_available()
   initial_bn_check(structure)
   if(is_dbn_or_dbnfit(structure))
@@ -47,6 +47,7 @@ plot_network <- function(structure){
   nodes_uniq <- bnlearn::node.ordering(structure)
   nodes <- data.frame(id = nodes_uniq,
                       label = nodes_uniq,
+                      #font.size = 24,
                       level = node_levels(structure, nodes_uniq)[2,],
                       color.background = grDevices::rgb(red = 0.196, blue = 0.627,
                                              green = 0.302, alpha = 0.8),
@@ -136,6 +137,7 @@ expand_time_nodes <- function(name, acc, max, i){
 #' represents the present time.
 #' @param structure the structure or fit of the network.
 #' @param offset the blank space between time slices
+#' @param subset_nodes a vector containing the names of the subset of nodes to plot
 #' @return the visualization of the DBN
 #' @examples 
 #' \donttest{
@@ -145,8 +147,9 @@ expand_time_nodes <- function(name, acc, max, i){
 #' plot_dynamic_network(net)
 #' }
 #' @importFrom magrittr "%>%"
+#' @import data.table
 #' @export
-plot_dynamic_network <- function(structure, offset = 200){
+plot_dynamic_network <- function(structure, offset = 200, subset_nodes = NULL){
   check_opt_pkgs_available()
   initial_dbn_check(structure)
   numeric_arg_check(offset)
@@ -179,7 +182,7 @@ plot_dynamic_network <- function(structure, offset = 200){
 
   all_colors <- Reduce(function(acu, x){c(acu, rep(x, n_nodes_slice))}, color, NULL)
 
-  nodes <- data.frame(id = nodes_uniq,
+  nodes <- data.table(id = nodes_uniq,
                       label = nodes_uniq,
                       x = all_pos,
                       y = as.numeric(levels[2,]) * 100,
@@ -191,13 +194,18 @@ plot_dynamic_network <- function(structure, offset = 200){
                       shadow = FALSE,
                       physics = FALSE)
 
-  edges <- data.frame(from = bnlearn::arcs(structure)[,1],
+  edges <- data.table(from = bnlearn::arcs(structure)[,1],
                       to = bnlearn::arcs(structure)[,2],
                       arrows = "to",
                       #color = "orange",
                       #smooth = TRUE,
                       shadow = FALSE,
                       color = "black")
+  
+  if(!is.null(subset_nodes)){
+    nodes <- nodes[get("id") %in% subset_nodes] # Need the get("id") instead of simply id to remove an R CMD check note
+    edges <- edges[(get("to") %in% subset_nodes) & (get("from") %in% subset_nodes)]
+  }
 
   ret <- visNetwork::visNetwork(nodes, edges) %>%
     visNetwork::visOptions(highlightNearest = list(enabled = T, hover = T),
@@ -205,3 +213,18 @@ plot_dynamic_network <- function(structure, offset = 200){
 
   return(ret)
 }
+
+#' Plots a Bayesian networks or a dynamic Bayesian network
+#'
+#' Selects the appropriate function depending on the class of the object
+#' @param structure the structure or fit of the network.
+#' @param ... additional parameters for the visualization of a DBN
+#' @export
+plot_network <- function(structure, ...){
+  initial_bn_or_dbn_check(structure)
+  
+  if(is_dbn_or_dbnfit(structure))
+    plot_dynamic_network(structure, ...)
+  else
+    plot_static_network(structure)
+}
