@@ -38,6 +38,12 @@ initial_dbn_check <- function(obj){
                  deparse(substitute(obj))))
 }
 
+initial_bn_or_dbn_check <- function(obj){
+  if(!is_dbn_or_dbnfit(obj) && !is_bn_or_bnfit(obj))
+    stop(sprintf("%s must be of class 'bn', 'bn.fit', 'dbn' or 'dbn.fit'.",
+                 deparse(substitute(obj))))
+}
+
 initial_df_check <- function(obj){
   if(!is.data.frame(obj))
     stop(sprintf("%s must be of class 'data.frame' or 'data.table'.",
@@ -45,28 +51,36 @@ initial_df_check <- function(obj){
 }
 
 numeric_arg_check <- function(...){
-  invisible(sapply(list(...), function(x){
-    if(!is.numeric(x))
-      stop(sprintf("%s has to be numeric.", deparse(substitute(x))))
-    if(length(x) > 1)
-      stop(sprintf("%s cannot be a vector.", deparse(substitute(x))))
-  }))
+  var_names <- deparse_names(...)
+  arg_list <- list(...)
+  
+  for(i in 1:length(var_names)){
+    if(!is.numeric(arg_list[[i]]))
+      stop(sprintf("%s has to be numeric.", var_names[i]))
+    if(length(arg_list[[i]]) > 1)
+      stop(sprintf("%s cannot be a vector.", var_names[i]))
+  }
 }
 
 logical_arg_check <- function(...){
-  invisible(sapply(list(...), function(x){
-    if(!is.logical(x))
-      stop(sprintf("%s has to be logical", deparse(substitute(x))))
-    if(length(x) > 1)
-      stop(sprintf("%s cannot be a vector.", deparse(substitute(x))))
-  }))
+  var_names <- deparse_names(...)
+  arg_list <- list(...)
+  
+  for(i in 1:length(var_names)){
+    if(!is.logical(arg_list[[i]]))
+      stop(sprintf("%s has to be logical.", var_names[i]))
+    if(length(arg_list[[i]]) > 1)
+      stop(sprintf("%s cannot be a vector.", var_names[i]))
+  }
 }
 
 character_arg_check <- function(...){
-  invisible(sapply(list(...), function(x){
-    if(!is.character(x))
-      stop(sprintf("%s has to be of type character.", deparse(substitute(x))))
-  }))
+  var_names <- deparse_names(...)
+  arg_list <- list(...)
+  
+  for(i in 1:length(var_names))
+    if(!is.character(arg_list[[i]]))
+      stop(sprintf("%s has to be of type character.", var_names[i]))
 }
 
 null_or_character_arg_check <- function(...){
@@ -211,8 +225,8 @@ initial_mode_check <- function(obj){
 }
 
 initial_attr_check <- function(fit){
-  if(is.null(attr(fit, "mu")) || is.null(attr(fit, "sigma")))
-    fit <- add_attr_to_fit(fit)
+  if(is.null(attr(fit, "mu")) || is.null(attr(fit, "sigma")) || is.null(attr(fit, "size")))
+    fit <- add_attr_to_fit(fit, calc_size(fit))
   
   return(fit)
 }
@@ -271,3 +285,25 @@ dt_null_check <- function(dt, intra){
   if(is.null(dt) && intra)
     stop("the unfolded training dataset is NULL, so intra-slice arcs cannot be learnt.")
 }
+
+positive_arg_check <- function(...){
+  numeric_arg_check(...)
+  var_names <- deparse_names(...)
+  arg_list <- list(...)
+  
+  for(i in 1:length(var_names)){
+    if(arg_list[[i]] <= 0)
+      stop(sprintf("%s cannot be lesser than or equal to 0.", var_names[i]))
+  }
+}
+
+lesser_than_arg_check <- function(x1, x2){
+  if(x1 <= x2)
+    stop(sprintf("%s cannot be lesser than or equal to %s.", deparse(substitute(x1)), deparse(substitute(x2))))
+}
+
+initial_onerow_dt_check <- function(obj){
+  initial_df_check(obj)
+  if(!dim(obj)[1] == 1)
+    stop("the data.frame provided needs to have only one row.")
+}
